/* Include Files */
#include "KTag.h"

static uint8_t SubmenuIndex = 0;
static MenuItem_T const * const Submenus[] = 
{
    &GameMenuItem,
    &HardwareMenuItem
};
static const uint8_t N_SUBMENUS = (sizeof(Submenus) / sizeof(MenuItem_T *));

static void RootMenuOnFocus(bool IncludeDetails);
static MenuItem_T const * RootMenuOnSelect();
static void RootMenuOnIncrement();
static void RootMenuOnDecrement();

static const MenuItem_T Root_Menu_Item =
{
    .OnFocus = RootMenuOnFocus,
    .OnSelect = RootMenuOnSelect,
    .OnIncrement = RootMenuOnIncrement,
    .OnDecrement = RootMenuOnDecrement
    
};

MenuItem_T const * const RootMenu = &Root_Menu_Item;

static void RootMenuOnFocus(bool IncludeDetails)
{
    AudioAction_T audio_action = {.ID = AUDIO_PLAY_MENU_PROMPT, .Play_To_Completion = true, .Data = (void *)0x00};
    xQueueSend(xQueueAudio, &audio_action, 0);
    
    if (IncludeDetails == true)
    {
        if (Submenus[SubmenuIndex]->OnFocus != NULL)
        {
            Submenus[SubmenuIndex]->OnFocus(false);
        }
    }
}

static MenuItem_T const * RootMenuOnSelect()
{
    if (Submenus[SubmenuIndex]->OnSelect != NULL)
    {
        Submenus[SubmenuIndex]->OnSelect();
    }
    
    return Submenus[SubmenuIndex];
}

static void RootMenuOnIncrement()
{
    if (SubmenuIndex < (N_SUBMENUS -1))
    {
        SubmenuIndex++;
    }
    else
    {
        // Wrap around.
        SubmenuIndex = 0;
    }
        
    if (Submenus[SubmenuIndex]->OnFocus != NULL)
    {
        Submenus[SubmenuIndex]->OnFocus(false);
    }
}

static void RootMenuOnDecrement()
{
    if (SubmenuIndex > 0)
    {
        SubmenuIndex--;
    }
    else
    {
        // Wrap around.
        SubmenuIndex = (N_SUBMENUS -1);
    }    
        
    if (Submenus[SubmenuIndex]->OnFocus != NULL)
    {
        Submenus[SubmenuIndex]->OnFocus(false);
    }
}